@@ -1,5 +1,8 @@
 ## ---- include = FALSE---------------------------------------------------------
+NOT_CRAN <- identical(tolower(Sys.getenv("NOT_CRAN")), "true")
 knitr::opts_chunk$set(
+  purl = NOT_CRAN,
+  eval = NOT_CRAN,
   collapse = TRUE,
   comment = "#>"
 )
